pub enum Mapping {
Ascii,
Iso8859_10,
}Expand description
Mapping.
This enum lists all mappings that are included in embedded-graphics. It is used to automatically generate font data for all mappings and isn’t normally used in applications.
Variants
Implementations
Sourceimpl Mapping
impl Mapping
Sourcepub const fn glyph_mapping(self) -> &'static StrGlyphMapping<'static>
pub const fn glyph_mapping(self) -> &'static StrGlyphMapping<'static>
Returns a glyph mapping for this mapping.