MultiMonoTextStyleBuilder

Struct MultiMonoTextStyleBuilder 

pub struct MultiMonoTextStyleBuilder<'a, C> { /* private fields */ }
Text style builder for monospaced fonts.

Use this builder to create MultiMonoTextStyles for Text.

Examples

Render yellow text on a blue background

This uses the FONT_6X9 font, but other fonts can also be used.

use multi_mono_font::{ascii::FONT_6X9, MultiMonoTextStyle, MultiMonoTextStyleBuilder};
use embedded_graphics::{
    pixelcolor::Rgb565,
    prelude::*,
    text::Text,
};

let style = MultiMonoTextStyleBuilder::new()
    .font(&FONT_6X9)
    .text_color(Rgb565::YELLOW)
    .background_color(Rgb565::BLUE)
    .build();

let text = Text::new("Hello Rust!", Point::new(0, 0), style);

Transparent background

If a property is omitted, it will remain at its default value in the resulting MultiMonoTextStyle returned by .build(). This example draws white text with no background at all.

use multi_mono_font::{ascii::FONT_6X9, MultiMonoTextStyle, MultiMonoTextStyleBuilder};
use embedded_graphics::{
    pixelcolor::Rgb565,
    prelude::*,
    text::Text,
};

let style = MultiMonoTextStyleBuilder::new()
    .font(&FONT_6X9)
    .text_color(Rgb565::WHITE)
    .build();

let text = Text::new("Hello Rust!", Point::new(0, 0), style);

Modifying an existing style

The builder can also be used to modify an existing style.

use multi_mono_font::{ascii::FONT_6X9, MultiMonoTextStyle, MultiMonoTextStyleBuilder};
use embedded_graphics::{
    pixelcolor::Rgb565,
    prelude::*,
    text::Text,
};

let style = MultiMonoTextStyle::new(&FONT_6X9, Rgb565::YELLOW);

let style_larger = MultiMonoTextStyleBuilder::from(&style)
    .font(&FONT_10X20)
    .build();

Implementations

Source

impl<'a, C> MultiMonoTextStyleBuilder<'a, C>
where C: PixelColor,

pub const fn new(text_color: C) -> Self

Creates a new text style builder.

pub const fn font<'b>( self, font_list: &'b [&'b MultiMonoFont<'b>], line_height: MultiMonoLineHeight, ) -> MultiMonoTextStyleBuilder<'b, C>

Sets the font.

pub const fn reset_background_color(self) -> Self

Resets the background color to transparent.

pub const fn text_color(self, text_color: C) -> Self

Sets the text color.

pub const fn line_height(self, line_height: MultiMonoLineHeight) -> Self

Sets the line height.

pub const fn background_color(self, background_color: C) -> Self

Sets the background color.

pub const fn build(self) -> MultiMonoTextStyle<'a, C>

Builds the text style.

This method can only be called after a font was set by using the font method. All other settings are optional and they will be set to their default value if they are missing.