pub struct StaticText<'a, S> {
pub text: &'a str,
pub rectangle: Rectangle,
pub character_style: S,
pub alignment: Alignment,
pub baseline: Baseline,
}Expand description
StaticText drawable.
A text drawable can be used to draw text to a draw target.
See the module-level documentation for more information about text drawables and examples.
Fields
text: &'a strThe string.
rectangle: RectangleThe position.
character_style: SThe character style.
alignment: AlignmentHorizontal text alignment.
baseline: BaselineText baseline.
Implementations
Sourceimpl<'a, S> StaticText<'a, S>
impl<'a, S> StaticText<'a, S>
Sourcepub const fn new(
text: &'a str,
rectangle: Rectangle,
character_style: S,
) -> Self
pub const fn new( text: &'a str, rectangle: Rectangle, character_style: S, ) -> Self
Creates a text drawable with the default text style.
Sourcepub const fn with_style(
text: &'a str,
rectangle: Rectangle,
character_style: S,
alignment: Alignment,
baseline: Baseline,
) -> Self
pub const fn with_style( text: &'a str, rectangle: Rectangle, character_style: S, alignment: Alignment, baseline: Baseline, ) -> Self
Creates a text drawable with the given alignment and baseline.
pub fn fill_with_style<C, D>(
&self,
style: PrimitiveStyle<C>,
target: &mut D,
) -> Result<Point, D::Error>where
C: PixelColor,
D: DrawTarget<Color = C>,
Sourceimpl<S: TextRenderer> StaticText<'_, S>
impl<S: TextRenderer> StaticText<'_, S>
pub fn clear<D>(&self, target: &mut D) -> Result<Point, D::Error>where
D: DrawTarget<Color = S::Color>,
pub fn clear_by_color<C, D>(
&self,
color: C,
target: &mut D,
) -> Result<Point, D::Error>where
C: PixelColor,
D: DrawTarget<Color = C>,